@@ -8,7 +8,7 @@ import torch
 
 from .data_models import BenchmarkConfig
 from .dataset_configs import get_all_dataset_configs
-from .enums import Device
+from .enums import Device, GenerativeType
 from .exceptions import InvalidBenchmark
 from .languages import get_all_languages
 from .tasks import SPEED, get_all_tasks
@@ -42,10 +42,11 @@ def build_benchmark_config(
     num_iterations: int,
     api_base: str | None,
     api_version: str | None,
+    gpu_memory_utilization: float,
+    generative_type: GenerativeType | None,
     debug: bool,
     run_with_cli: bool,
-    only_allow_safetensors: bool,
-    first_time: bool = False,
+    requires_safetensors: bool,
 ) -> BenchmarkConfig:
     """Create a benchmark configuration.
 
@@ -102,15 +103,20 @@ def build_benchmark_config(
             model on an inference API.
         api_version:
             The version of the API to use for a given inference API.
+        gpu_memory_utilization:
+            The GPU memory utilization to use for vLLM. A larger value will result in
+            faster evaluation, but at the risk of running out of GPU memory. Only reduce
+            this if you are running out of GPU memory. Only relevant if the model is
+            generative.
+        generative_type:
+            The type of generative model. Only relevant if the model is generative. If
+            not specified, the type will be inferred automatically.
         debug:
             Whether to run the benchmark in debug mode.
         run_with_cli:
             Whether the benchmark is being run with the CLI.
-        only_allow_safetensors:
+        requires_safetensors:
             Whether to only allow evaluations of models stored as safetensors.
-        first_time:
-            Whether this is the first time the benchmark configuration is being created.
-            Defaults to False.
 
     Returns:
         The benchmark configuration.
@@ -154,9 +160,11 @@ def build_benchmark_config(
         num_iterations=num_iterations,
         api_base=api_base,
         api_version=api_version,
+        gpu_memory_utilization=gpu_memory_utilization,
+        generative_type=generative_type,
         debug=debug,
         run_with_cli=run_with_cli,
-        only_allow_safetensors=only_allow_safetensors,
+        requires_safetensors=requires_safetensors,
     )
 
 
